@@ -1,8 +1,7 @@
-from dagster.cli.workspace import get_workspace_from_kwargs
+from dagster.cli.workspace import get_workspace_process_context_from_kwargs
 from dagster.core.test_utils import instance_for_test
 from dagster.utils import file_relative_path
 from dagster_graphql.client.query import LAUNCH_PIPELINE_EXECUTION_MUTATION, SUBSCRIPTION_QUERY
-from dagster_graphql.implementation.context import DagsterGraphQLContext
 from dagster_graphql.schema import create_schema
 from dagster_graphql.test.utils import execute_dagster_graphql, infer_pipeline_selector
 from graphql import graphql
@@ -11,22 +10,24 @@ from graphql.execution.executors.sync import SyncExecutor
 
 def test_execute_hammer_through_dagit():
     with instance_for_test() as instance:
-        with get_workspace_from_kwargs(
-            {
+        with get_workspace_process_context_from_kwargs(
+            instance,
+            version="",
+            read_only=False,
+            kwargs={
                 "python_file": file_relative_path(
                     __file__, "../../../dagster-test/dagster_test/toys/hammer.py"
                 ),
                 "attribute": "hammer_pipeline",
-            }
-        ) as workspace:
-            context = DagsterGraphQLContext(workspace=workspace, instance=instance,)
+            },
+        ) as workspace_process_context:
+            context = workspace_process_context.create_request_context()
             selector = infer_pipeline_selector(context, "hammer_pipeline")
             executor = SyncExecutor()
 
             variables = {
                 "executionParams": {
                     "runConfigData": {
-                        "intermediate_storage": {"filesystem": {}},
                         "execution": {"dask": {"config": {"cluster": {"local": {}}}}},
                     },
                     "selector": selector,
@@ -60,5 +61,5 @@ def test_execute_hammer_through_dagit():
                 x["__typename"] for x in subscribe_results[0].data["pipelineRunLogs"]["messages"]
             ]
 
-            assert "PipelineStartEvent" in messages
-            assert "PipelineSuccessEvent" in messages
+            assert "RunStartEvent" in messages
+            assert "RunSuccessEvent" in messages
